@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: auth.h,v 1.1.1.1 2006/01/06 13:53:23 dembour Exp $
+** $Id: auth.h,v 1.4 2008/08/26 15:49:59 dembour Exp $
 **
 ** 
 ** This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,9 @@
 #ifndef __AUTH_H__
 #define __AUTH_H__
 
-int		list_ressources(t_conf *conf, struct sockaddr_in *);
-uint16_t        connect_ressource(t_conf *conf, struct sockaddr_in *);
+int		list_resources(t_conf *conf);
+uint16_t	connect_resource(t_conf *conf, uint16_t);
+uint16_t	create_session(t_conf *conf);
+
 #endif
 
