@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: control.h,v 1.5 2007/05/22 14:50:28 dembour Exp $
+** $Id: control.h,v 1.6.4.1 2009/12/28 15:11:16 dembour Exp $
 **
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -34,12 +34,18 @@ typedef	struct		s_control {
   uint16_t		nop_pending;
   uint16_t		data_pending;
   uint8_t		cumul_errors;
+#ifdef _WIN32
+  WSAEVENT		event;
+  OVERLAPPED		aio;
+  int			io_pending;
+#endif
   struct sockaddr_in	peer;
 }			t_control;
 
 typedef struct		s_control_peer {
   uint16_t		ack_seq;
   uint16_t		id;
+  uint16_t		old_id;
   uint8_t		type;
 }			t_control_peer;
 
