@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: queue.h,v 1.2 2006/01/09 08:41:19 dembour Exp $
+** $Id: queue.h,v 1.3 2008/08/26 15:49:59 dembour Exp $
 **
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 
 t_list	*init_queue();
 int	delete_queue(t_list *queue);
-int	queue_get_udp_data(t_conf *conf, struct s_simple_list *client);
+int	queue_get_udp_data(t_conf *conf, char *buffer, int len);
 int	queue_get_tcp_data(t_conf *conf, struct s_simple_list *client);
 int	check_for_resent(t_conf *conf);
 int	queue_put_nop(t_conf *conf, struct s_simple_list *client);
