@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: requests.h,v 1.2 2006/01/09 08:41:19 dembour Exp $
+** $Id: requests.h,v 1.6.4.2 2010/06/02 14:30:25 collignon Exp $
 **
 ** 
 ** This program is free software; you can redistribute it and/or modify
@@ -21,15 +21,24 @@
 #ifndef __REQUESTS_H__
 #define  __REQUESTS_H__
 
-void	create_req_hdr(void *, t_conf *);
-int	add_query(struct dns_hdr *, void *, char *, 
-		  t_conf *, uint16_t );
-void	data2qname(void *,int , void *, t_conf *);
-int	result2data(void *, char *, int);
-void	*jump_qname(void *);
+typedef struct		s_request {
+  union			 {
+    char		data[MAX_EDNS_LEN];
+    t_packet		packet;
+  }			u;
+#define req_data	u.data
+  int			len;
+  uint16_t		type;
+  char			*domain;
+  struct s_rr_functions *request_functions;
+}			t_request;
 
-int	create_req_data(t_conf *conf, struct s_simple_list *client, struct s_list *queue, char *data, int len);
-
-struct rr_hdr	*get_reply(void *data, int len);
+int		add_edns(t_conf *conf, void *buffer, int len);
+int		push_req_data(t_conf *conf, struct s_simple_list *client, struct s_list *queue, t_request *req);
+int		transceive_query(t_conf *, t_request *, char *, int );
+uint16_t	send_query(t_conf *conf, struct s_request *);
+int		decode_reply(char *query, int in_len, char *output, int max_len);
+int		create_simple_req(t_conf *, t_request *, char *, char *, uint16_t);
+uint8_t		query_is_compressed(char *buffer, uint16_t len);
 
 #endif
