@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: socket.h,v 1.2 2006/01/17 13:01:58 dembour Exp $
+** $Id: socket.h,v 1.4.4.3 2009/12/28 15:11:16 dembour Exp $
 **
 ** 
 ** This program is free software; you can redistribute it and/or modify
@@ -21,8 +21,16 @@
 #ifndef __SOCKET_H__
 #define __SOCKET_H__
 
-int	bind_socket(t_conf *);
-int	create_socket(t_conf *, struct sockaddr_in *);
-int	get_simple_reply(t_conf *, void *, uint16_t);
+
+#ifndef _WIN32
+#define IS_THIS_SOCKET(sd, handle, descriptors, offset)		FD_ISSET((sd), (descriptors))
+#else
+#define IS_THIS_SOCKET(sd, handle, descriptors, offset)		(((offset) <= HANDLE_SIZE) && (descriptors[offset] == handle))
+#endif
+
+int		socket_is_valid(socket_t );
+int		bind_socket(t_conf *);
+socket_t	create_socket(t_conf *);
+uint16_t	get_simple_reply(t_conf *, char *, uint16_t);
 
 #endif
