@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: main.c,v 1.6 2007/05/30 13:04:45 dembour Exp $
+** $Id: main.c,v 1.12.4.4 2009/12/28 15:11:15 dembour Exp $
 **
 ** 
 ** This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 #include <sys/types.h>
 
 #ifndef _WIN32
-#include <unistd.h>
 #include <sys/time.h>
 #else
 #include "mywin32.h"
@@ -37,19 +36,31 @@
 #include "myerror.h"
 #include "dns.h"
 
+/**
+ * @brief main part
+ * @retval 0 on success
+ * @retval -1 on error
+ **/
 
 int			main(int argc, char **argv)
 {
   t_conf		conf;
-  struct sockaddr_in	sa;
-
+  
   if ((get_option(argc, argv, &conf)) ||  
-      ((conf.sd_udp = create_socket(&conf, &sa)) < 0))
-      return (-1);
+      ((conf.sd_udp = create_socket(&conf)) == -1))
+    return (-1);
   srand(getpid() ^ (unsigned int) time(0));
-  if (!conf.ressource)
-    return (list_ressources(&conf, &sa));
-  if (! bind_socket(&conf))
-    do_client(&conf, &sa);
+#ifdef _WIN32
+  if (!(conf.event_udp = WSACreateEvent()))
+    {
+      MYERROR("WSACreateEvent error\n");
+      return (-1);
+    }
+  WSAEventSelect(conf.sd_udp, conf.event_udp, FD_READ);
+#endif
+  if (!conf.resource)
+    return (list_resources(&conf));
+  if ((!conf.local_port) || (!bind_socket(&conf)))
+    do_client(&conf);
   return (0);
 }
