@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: base64.h,v 1.2 2006/01/09 08:41:19 dembour Exp $
+** $Id: base64.h,v 1.3 2008/08/04 15:31:07 dembour Exp $
 **
 ** 
 ** This program is free software; you can redistribute it and/or modify
@@ -27,8 +27,8 @@
   each bloc is 3 of real data
 */
 
-#define	BASE64_SIZE(len)	((((len) / 3 ) + 3-1 ) * 4)
-#define	DECODE_BASE64_SIZE(len) ((((len)/4)*3))
+#define	BASE64_SIZE(len)		((( (len + 3 - 1 ) / 3 )) * 4)
+#define	DECODED_BASE64_SIZE(len)	((( (len) / 4 ) * 3 ))
 
 
 /* 
