@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: myerror.h,v 1.2 2007/01/16 15:31:55 dembour Exp $
+** $Id: myerror.h,v 1.2.6.1 2009/09/07 17:11:57 dembour Exp $
 **
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -23,20 +23,11 @@
 
 #include <stdio.h>
 
-#ifndef _WIN32
 #define MYERROR(fmt, args...) \
 { \
         fprintf(stderr, "Error %s:%d ", __FILE__, __LINE__); \
 	fprintf(stderr, fmt, ##args); \
 	fprintf(stderr, "\n"); \
  }
-#else
-#define MYERROR(fmt, ...) \
-{ \
-        fprintf(stderr, "Error %s:%d ", __FILE__, __LINE__); \
-		fprintf(stderr, ##fmt); \
-	fprintf(stderr, "\n"); \
- }
-#endif
 
 #endif
