@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Nicolas COLLIGNON
-** $Id: mywin32.h,v 1.4 2007/02/13 10:31:14 collignon Exp $
+** $Id: mywin32.h,v 1.5.4.4 2009/12/28 15:11:17 dembour Exp $
 **
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -21,34 +21,25 @@
 #ifndef __MY_WIN32_H__
 #define __MY_WIN32_H__
 
+#ifndef _WIN32_WINNT
+#define _WIN32_WINNT 0x0501
+#endif
+
 #include <winsock2.h>
+#include <time.h>
+#include <stdint.h>
 
-typedef unsigned char uint8_t;
-typedef signed char int8_t;
-typedef unsigned short uint16_t;
-typedef signed short int16_t;
-typedef unsigned long uint32_t;
-typedef signed long int32_t;
+typedef SOCKET socket_t;
+typedef HANDLE process_t;
 
-#define socket_t SOCKET
+#define getpid		GetCurrentProcessId
 
-#define getpid GetCurrentProcessId
+#define strncasecmp	_strnicmp
 
-#define strncasecmp _strnicmp
+#define read(f,b,l)	recv(f, b, (int) l, 0)
+#define write(f,b,l)	send(f, b, (int) l, 0)
 
-#define read(f,b,l)  recv(f, b, (int) l, 0)
-#define write(f,b,l) send(f, b, (int) l, 0)
-
-#define close closesocket
-
-extern char *optarg;
-int getopt(int, char * const *, const char *);
-
-int __inline gettimeofday(struct timeval *tv, void *bla)
-{
-  tv->tv_sec  = (long) time(NULL);
-  tv->tv_usec = 0;
-  return 0;
-}
+#define close		closesocket
+#define HANDLE_SIZE	1024
 
 #endif
