@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: auth.h,v 1.3 2006/11/17 15:50:16 dembour Exp $
+** $Id: auth.h,v 1.6 2008/08/26 15:50:00 dembour Exp $
 **
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,9 @@
 #ifndef __AUTH_H__
 #define __AUTH_H__
 
-int login_user(t_conf *conf, void  *packet, void *buffer, int len,  struct sockaddr_in *sa);
-uint16_t create_env(t_conf *conf, void *req, char *ressource, int in_len);
+int	login_user(t_conf *conf, t_request *, t_packet *, t_simple_list *);
+uint16_t create_env(t_conf *conf, void *req, char *resource, int in_len);
+uint8_t is_authenticated(t_conf *, void *req, int in_len);
+int	 bind_user(t_conf *conf, t_request *, t_packet *, t_simple_list *);
 
 #endif
