@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: control.h,v 1.3 2006/01/17 13:01:59 dembour Exp $
+** $Id: control.h,v 1.5.4.3 2010/01/20 16:14:26 collignon Exp $
 **
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -21,22 +21,28 @@
 #ifndef __CONTROL_H__
 #define __CONTROL_H__
 
-/* client */
+#include "mycrypto.h"
+
+/* client related struct : info & parameters */
 typedef	struct		s_control {
+
   uint8_t		req;		/* first req acceptable */
   uint8_t		queue_full;	
-  uint8_t		use_compress;    
-  struct timeval	tv;
-  char			*hash_wanted;
+  uint8_t		use_compress;
+  uint16_t		mtu_size;	/* max encoded data */
+  uint16_t		nb_reply;	/* how many reply can we send */
+  struct timeval	tv;		/* client timeout */
+  uint8_t		authenticated;
+  char			challenge[CHALLENGE_SIZE+1];
 }			t_control;
 
-/* packet */
+/* packet related */
 typedef	struct		s_control_peer {
   struct sockaddr_in	sa;
   char			data[MAX_HOST_NAME_ENCODED];
   int			len;
   uint16_t		seq;
+  const struct s_rr_functions	*reply_functions;
 }			t_control_peer;
 
-
 #endif
