@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: dns_decode.h,v 1.2 2007/02/02 16:56:41 dembour Exp $
+** $Id: dns_decode.h,v 1.3 2008/03/14 08:49:21 dembour Exp $
 **
 ** 
 ** This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,6 @@
 #ifndef __DNS_DECODE_H__
 #define __DNS_DECODE_H__
 
-int	dns_decode(char *, char *, char *, t_conf *, struct sockaddr_in *);
+int	dns_decode(t_conf *conf, t_request *req, char *input, char *output);
 
 #endif
