@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: queue.h,v 1.1 2006/06/30 07:39:09 dembour Exp $
+** $Id: queue.h,v 1.4 2009/01/09 16:40:14 dembour Exp $
 **
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,14 @@
 #ifndef __QUEUE_H__
 #define __QUEUE_H__
 
-void	queue_dump(struct s_simple_list *client);
+int		queue_put_data(t_conf *conf, t_request *req, t_data *data);
+t_list		*init_queue();
+int		queue_read_tcp(t_conf *conf, t_simple_list *client);
+int		queue_delete_zombie(t_conf * conf);
+void		client_update_timer(struct s_simple_list *client);
+int		delete_queue(struct s_list *queue);
+t_simple_list   *find_client_by_session_id(t_conf *conf, uint16_t session_id);
+void            queue_dump(t_simple_list *client);
+int		queue_flush_expired_data(t_conf *conf);
 
 #endif
