@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: requests.h,v 1.1.1.1 2006/01/06 13:53:23 dembour Exp $
+** $Id: requests.h,v 1.4.4.2 2010/02/10 15:29:51 dembour Exp $
 **
 ** 
 ** This program is free software; you can redistribute it and/or modify
@@ -21,8 +21,19 @@
 #ifndef __REQUESTS_H__
 #define  __REQUESTS_H__
 
+typedef struct s_command {
+  const char	*str;
+  uint8_t	str_len;
+  uint8_t	authenticated;
+  int		(*deal_cmd)(t_conf *, t_request *, t_packet *, t_simple_list *);
+}		t_command;
+
 int	get_incoming_request(t_conf *);
+int	send_reply(t_conf *conf, t_request *req, t_data *data);
+int	send_ascii_reply(t_conf *conf, t_request *req, t_packet *packet, char *data);
 void    *add_reply(struct dns_hdr *, void *, uint16_t , char *);
-int     build_error_reply(t_conf *, void *, int , char *);
+int	get_request(t_conf *conf, t_request *req, t_data *output);
+int	send_resources_reply(t_conf *conf, t_request *, t_packet *, t_simple_list *);
+
 
 #endif
