@@ -1,6 +1,6 @@
 /*
 ** Copyright (C) 2006 Olivier DEMBOUR
-** $Id: socket.h,v 1.1.1.1 2006/01/06 13:53:23 dembour Exp $
+** $Id: socket.h,v 1.1.1.1.6.1 2010/01/06 12:50:41 dembour Exp $
 **
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -22,6 +22,14 @@
 #define __SOCKET_H__
 
 #include <netinet/in.h>
+#include <sys/socket.h>
+
+union	sockaddr_u			{
+  struct sockaddr_storage	storage;
+  struct sockaddr_in		in;
+  struct sockaddr_in6		in6;
+  struct sockaddr		sockaddr;
+};
 
 int connect_socket(char *, uint16_t, int *);
 int bind_socket(t_conf *);
